@@ -24,7 +24,7 @@ class CTkDialog:
         self.fg_color = CTkColorManager.MAIN if fg_color == "CTkColorManager" else fg_color
         self.hover_color = CTkColorManager.MAIN_HOVER if hover_color == "CTkColorManager" else hover_color
 
-        self.top = tkinter.Toplevel()
+        self.top = customtkinter.CTkToplevel()
         self.top.geometry(f"280x{self.height}")
         self.top.resizable(False, False)
         self.top.title(title)
@@ -32,19 +32,22 @@ class CTkDialog:
         self.top.focus_force()
         self.top.grab_set()
 
-        self.label_frame = tkinter.Frame(master=self.top,
-                                         width=300,
-                                         height=self.height-100)
+        self.label_frame = customtkinter.CTkFrame(master=self.top,
+                                                  corner_radius=0,
+                                                  width=300,
+                                                  height=self.height-100)
         self.label_frame.place(relx=0.5, rely=0, anchor=tkinter.N)
 
-        self.button_and_entry_frame = tkinter.Frame(master=self.top,
-                                                    width=300,
-                                                    height=100)
+        self.button_and_entry_frame = customtkinter.CTkFrame(master=self.top,
+                                                             corner_radius=0,
+                                                             width=300,
+                                                             height=100)
         self.button_and_entry_frame.place(relx=0.5, rely=1, anchor=tkinter.S)
 
         self.myLabel = CTkLabel(master=self.label_frame,
                                 text=text,
                                 width=300,
+                                fg_color=None,
                                 height=self.height-100)
         self.myLabel.place(relx=0.5, rely=0.5, anchor=tkinter.CENTER)
 
@@ -68,7 +71,10 @@ class CTkDialog:
                                        hover_color=self.hover_color)
         self.cancel_button.place(relx=0.72, rely=0.65, anchor=tkinter.CENTER)
 
-    def ok_event(self):
+        self.entry.entry.focus_force()
+        self.entry.bind("<Return>", self.ok_event)
+
+    def ok_event(self, event=None):
         self.user_input = self.entry.get()
         self.running = False
 
@@ -89,18 +95,17 @@ class CTkDialog:
 
 if __name__ == "__main__":
     import customtkinter
-    customtkinter.enable_macos_darkmode()
     customtkinter.set_appearance_mode("System")
 
-    app = tkinter.Tk()
+    app = customtkinter.CTk()
+    app.geometry("400x300")
     app.title("CTkDialog Test")
 
     def button_click_event():
-        dialog = CTkDialog(master=None, text="Type in a number:", title="Test", fg_color="green", hover_color="darkgreen")
+        dialog = CTkDialog(master=None, text="Type in a number:", title="Test")
         print("Number:", dialog.get_input())
 
     button = CTkButton(master=app, text="Open Dialog", command=button_click_event)
     button.place(relx=0.5, rely=0.5, anchor=tkinter.CENTER)
 
     app.mainloop()
-    customtkinter.disable_macos_darkmode()
